<?php
/*
 * spkrWatchdog.php is to be used for the following purposes:
 * 1) provides a 'scanning LED' output that occurs when the file 'cylon' exists in the state folder.
 * 2) provides a 'flashing leds' output that occurs when the file 'flash' exists in the state folder.
 * 3) pings the katoombasound IP address once every ten minutes to keep the network alive.
 * 4) TBD - it monitors critical functions and if they fail for an extended period (2 minutes?) then the device is returned to safe code and default settings
 *
 * In order to ensure maximum reliability, spkrWatchdog.php does not rely on other PHP files or any external data (settings etc).
 * And, it is never touched by the user operations.
 * That is also why the ping keep alive IP address is hard coded and the periodicity is also hard coded.
 * If you do decide to make the keep alive IP and periodicity user configurable, make sure you revert to sane defaults if the settings file cannot be accessed for any reason.
*/

// TBD - We want to try to rescue the i2cbus to get it going again since this script exits if it cannot access i2c bus 0 or 1. Add reset code right here.

exec('i2cget -y 0 0x21', $output, $returned);
if(strlen($returned)>0) $i2cbus='0';
else{
    exec('i2cget -y 1 0x21', $output, $returned);
    if(strlen($returned)>0) $i2cbus='1';
    else {
        echo "ERROR: spkrWatchdog.php could not access i2c bus. Sleeping 10 seconds.\n";
        sleep(10);
        exit;
    }
}
// set IO port LED pins to pull ups
exec('i2cset -y '.$i2cbus.' 0x22 0x06 0xff');
exec('i2cset -y '.$i2cbus.' 0x21 0x06 0xff');
exec('i2cset -y '.$i2cbus.' 0x22 0x00 0x55');
exec('i2cset -y '.$i2cbus.' 0x21 0x00 0x55');
exec('i2cset -y '.$i2cbus.' 0x24 0x00 0x00');

$speed=25000;
$pingTime=60;
$lastPingTime=0;

// and then continue into main...
while(1){
    while(file_exists("/var/www/html/state/cylon")){
        for($count=0;$count<8;$count++){
            $mask=(1<<$count)^0xfd;
            exec('i2cset -y '.$i2cbus.' 0x22 0x09 '.$mask);
            usleep($speed);
        }
        for($count=0;$count<7;$count++){
            $mask=(1<<$count)^0xff;
            exec('i2cset -y '.$i2cbus.' 0x21 0x09 '.$mask);
            usleep($speed);
        }
        for($count=7;$count>=0;$count--){
            $mask=(1<<$count)^0xff;
        exec('i2cset -y '.$i2cbus.' 0x21 0x09 '.$mask);
            usleep($speed);
        }
        for($count=6;$count>=0;$count--){
            $mask=(1<<$count)^0xfd;
            exec('i2cset -y '.$i2cbus.' 0x22 0x09 '.$mask);
            usleep($speed);
        }
    }
    while(file_exists("/var/www/html/state/flash")){
        // leds on
        exec('i2cset -y '.$i2cbus.' 0x22 0x09 0x02');
        exec('i2cset -y '.$i2cbus.' 0x21 0x09 0x00');
        usleep(500000);
        // leds off
        exec('i2cset -y '.$i2cbus.' 0x22 0x09 0xA8');
        exec('i2cset -y '.$i2cbus.' 0x21 0x09 0xAA');
        usleep(500000);

        $counter = file_get_contents("/var/www/html/state/flash");
        if(is_numeric($counter--)){
            if($counter>0) file_put_contents("/var/www/html/state/flash",$counter);
            else unlink("/var/www/html/state/flash");
        } else unlink("/var/www/html/state/flash");
    }
    // do the network keep alive
    $now=time();
    if($now-$pingTime>=$lastPingTime){
        $lastPingTime=$now;
        exec('ping -c1 69.163.177.231');
    }
    sleep(1);
}
?>